@@ -1,6 +1,7 @@
 import math
 from io import BytesIO
 from typing import List, Union
+from PIL.Image import Image as IMG
 from typing_extensions import Literal
 
 from nonebot.params import Depends
@@ -40,7 +41,7 @@ __plugin_meta__ = PluginMetadata(
         "unique_name": "petpet",
         "example": "摸 @小Q\n摸 114514\n摸 自己\n摸 [图片]",
         "author": "meetwq <meetwq@gmail.com>",
-        "version": "0.3.9",
+        "version": "0.3.10",
     },
 )
 
@@ -65,20 +66,23 @@ def help_image(user_id: str, memes: List[Meme]) -> BytesIO:
             texts.append(text)
         return "\n".join(texts)
 
-    text1 = "摸头等头像相关表情制作\n触发方式：指令 + @某人 / qq号 / 自己 / [图片]\n支持的指令："
-    idx = math.ceil(len(memes) / 2)
-    text2 = cmd_text(memes[:idx])
-    text3 = cmd_text(memes[idx:], start=idx + 1)
-    img1 = Text2Image.from_text(text1, 30, weight="bold").to_image(padding=(20, 10))
-    img2 = Text2Image.from_bbcode_text(text2, 30).to_image(padding=(20, 10))
-    img3 = Text2Image.from_bbcode_text(text3, 30).to_image(padding=(20, 10))
-    w = max(img1.width, img2.width + img3.width)
-    h = img1.height + max(img2.height, img2.height)
-    img = BuildImage.new("RGBA", (w, h), "white")
-    img.paste(img1, alpha=True)
-    img.paste(img2, (0, img1.height), alpha=True)
-    img.paste(img3, (img2.width, img1.height), alpha=True)
-    return img.save_jpg()
+    head_text = "摸头等头像相关表情制作\n触发方式：指令 + @某人 / qq号 / 自己 / [图片]\n支持的指令："
+    head = Text2Image.from_text(head_text, 30, weight="bold").to_image(padding=(20, 10))
+    imgs: List[IMG] = []
+    col_num = 3
+    num_per_col = math.ceil(len(memes) / col_num)
+    for idx in range(0, len(memes), num_per_col):
+        text = cmd_text(memes[idx : idx + num_per_col], start=idx + 1)
+        imgs.append(Text2Image.from_bbcode_text(text, 30).to_image(padding=(20, 10)))
+    w = max(sum((img.width for img in imgs)), head.width)
+    h = head.height + max((img.height for img in imgs))
+    frame = BuildImage.new("RGBA", (w, h), "white")
+    frame.paste(head, alpha=True)
+    current_w = 0
+    for img in imgs:
+        frame.paste(img, (current_w, head.height), alpha=True)
+        current_w += img.width
+    return frame.save_jpg()
 
 
 def get_user_id():
