@@ -1391,7 +1391,7 @@ def teach(img: BuildImage = UserImg(), arg: str = Arg()):
         frame.draw_text(
             (10, frame.height - 80, frame.width - 10, frame.height - 5),
             arg,
-            max_fontsize=45,
+            max_fontsize=50,
             fill="white",
             stroke_fill="black",
             stroke_ratio=0.06,
@@ -1405,3 +1405,101 @@ def teach(img: BuildImage = UserImg(), arg: str = Arg()):
         )
 
     return make_jpg_or_gif(img, make)
+
+
+def addition(img: BuildImage = UserImg(), arg: str = Arg()):
+    frame = load_image("addiction/0.png")
+
+    if arg:
+        expand_frame = BuildImage.new("RGBA", (246, 286), "white")
+        expand_frame.paste(frame)
+        try:
+            expand_frame.draw_text(
+                (10, 246, 236, 286),
+                arg,
+                max_fontsize=45,
+                lines_align="center",
+            )
+        except ValueError:
+            return TEXT_TOO_LONG
+        frame = expand_frame
+
+    def make(img: BuildImage) -> BuildImage:
+        return frame.copy().paste(img.resize((70, 70), keep_ratio=True), (0, 0))
+
+    return make_jpg_or_gif(img, make)
+
+
+def gun(img: BuildImage = UserImg(), arg=NoArg()):
+    frame = load_image("gun/0.png")
+    frame.paste(img.convert("RGBA").resize((500, 500), keep_ratio=True), below=True)
+    return frame.save_jpg()
+
+
+def blood_pressure(img: BuildImage = UserImg(), arg=NoArg()):
+    frame = load_image("blood_pressure/0.png")
+
+    def make(img: BuildImage) -> BuildImage:
+        return frame.copy().paste(
+            img.resize((414, 450), keep_ratio=True), (16, 17), below=True
+        )
+
+    return make_jpg_or_gif(img, make)
+
+
+def read_book(img: BuildImage = UserImg(), arg: str = Arg()):
+    frame = load_image("read_book/0.png")
+    points = ((0, 108), (1092, 0), (1023, 1134), (29, 1134))
+    img = img.convert("RGBA").resize((1000, 1100), keep_ratio=True, direction="north")
+    cover = img.perspective(points)
+    frame.paste(cover, (1138, 1172), below=True)
+    if arg:
+        chars = list(" ".join(arg.splitlines()))
+        pieces: List[BuildImage] = []
+        for char in chars:
+            piece = BuildImage(
+                Text2Image.from_text(char, 200, fill="white", weight="bold").to_image()
+            )
+            if re.fullmatch(r"[a-zA-Z0-9\s]", char):
+                piece = piece.rotate(-90, expand=True)
+            else:
+                piece = piece.resize_canvas((piece.width, piece.height - 40), "south")
+            pieces.append(piece)
+        w = max((piece.width for piece in pieces))
+        h = sum((piece.height for piece in pieces))
+        if w > 240 or h > 3000:
+            return TEXT_TOO_LONG
+        text_img = BuildImage.new("RGBA", (w, h))
+        h = 0
+        for piece in pieces:
+            text_img.paste(piece, ((w - piece.width) // 2, h), alpha=True)
+            h += piece.height
+        if h > 780:
+            ratio = 780 / h
+            text_img = text_img.resize((int(w * ratio), int(h * ratio)))
+        text_img = text_img.rotate(3, expand=True)
+        w, h = text_img.size
+        frame.paste(text_img, (870 + (240 - w) // 2, 1500 + (780 - h) // 2), alpha=True)
+    return frame.save_jpg()
+
+
+def call_110(
+    user_imgs: List[BuildImage] = UserImgs(1, 2),
+    sender_img: BuildImage = SenderImg(),
+    arg=NoArg(),
+):
+    if len(user_imgs) >= 2:
+        img1 = user_imgs[0]
+        img0 = user_imgs[1]
+    else:
+        img1 = sender_img
+        img0 = user_imgs[0]
+    img1 = img1.convert("RGBA").square().resize((250, 250))
+    img0 = img0.convert("RGBA").square().resize((250, 250))
+
+    frame = BuildImage.new("RGB", (900, 500), "white")
+    frame.draw_text((0, 0, 900, 200), "遇到困难请拨打", max_fontsize=100)
+    frame.paste(img1, (50, 200), alpha=True)
+    frame.paste(img1, (325, 200), alpha=True)
+    frame.paste(img0, (600, 200), alpha=True)
+    return frame.save_jpg()
